@@ -29,18 +29,20 @@ def create_coco_api(coco_records) -> COCO:
     return coco_ds
 
 
-def coco_api_from_preds(preds) -> COCO:
-    coco_preds = convert_preds_to_coco_style(preds)
+def coco_api_from_preds(preds, show_pbar: bool = False) -> COCO:
+    coco_preds = convert_preds_to_coco_style(preds, show_pbar=show_pbar)
     return create_coco_api(coco_preds)
 
 
-def coco_api_from_records(records) -> COCO:
+def coco_api_from_records(records, show_pbar: bool = False) -> COCO:
     """Create pycocotools COCO dataset from records"""
-    coco_records = convert_records_to_coco_style(records)
+    coco_records = convert_records_to_coco_style(records, show_pbar=show_pbar)
     return create_coco_api(coco_records=coco_records)
 
 
-def create_coco_eval(records, preds, metric_type: str) -> COCOeval:
+def create_coco_eval(
+    records, preds, metric_type: str, show_pbar: bool = False
+) -> COCOeval:
     assert len(records) == len(preds)
 
     for record, pred in zip(records, preds):
@@ -50,8 +52,8 @@ def create_coco_eval(records, preds, metric_type: str) -> COCOeval:
         # needs 'filepath' for mask `coco.py#418`
         pred["filepath"] = record["filepath"]
 
-    target_ds = coco_api_from_records(records)
-    pred_ds = coco_api_from_preds(preds)
+    target_ds = coco_api_from_records(records, show_pbar=show_pbar)
+    pred_ds = coco_api_from_preds(preds, show_pbar=show_pbar)
     return COCOeval(target_ds, pred_ds, metric_type)
 
 
@@ -78,7 +80,7 @@ def convert_record_to_coco_annotations(record):
         annotations_dict["category_id"].append(label)
 
     for bbox in record["bboxes"]:
-        annotations_dict["bbox"].append(bbox.xywh)
+        annotations_dict["bbox"].append(list(bbox.xywh))
 
     if "areas" in record:
         for area in record["areas"]:
@@ -90,28 +92,41 @@ def convert_record_to_coco_annotations(record):
     # HACK: Because of prepare_record, mask should always be `MaskArray`,
     # maybe the for loop is not required?
     if "masks" in record:
-        annotations_dict["segmentation"] = []
-        for mask in record["masks"]:
-            if isinstance(mask, MaskArray):
-                # HACK: see previous hack
-                assert len(mask.shape) == 2
-                mask2 = MaskArray(mask.data[None])
-                rles = mask2.to_coco_rle(record["height"], record["width"])
-                annotations_dict["segmentation"].extend(rles)
-            elif isinstance(mask, Polygon):
-                annotations_dict["segmentation"].append(mask.points)
-            elif isinstance(mask, RLE):
-                coco_rle = {
-                    "counts": mask.to_coco(),
-                    "size": [record["height"], record["width"]],
-                }
-                annotations_dict["segmentation"].append(coco_rle)
-            elif isinstance(mask, MaskFile):
-                rles = mask.to_coco_rle(record["height"], record["width"])
-                annotations_dict["segmentation"].extend(rles)
-            else:
-                msg = f"Mask type {type(mask)} unsupported, we only support RLE and Polygon"
-                raise ValueError(msg)
+        masks = record["masks"]
+
+        # TODO, HACK: We should always have EncodedRLEs
+        if isinstance(masks, EncodedRLEs):
+            annotations_dict["segmentation"] = masks.erles
+
+        else:
+            raise RuntimeError(
+                "masks are expected to be EncodedRLEs only, "
+                "if you get this error please open an issue on github."
+            )
+            # annotations_dict["segmentation"] = []
+            # for mask in record["masks"]:
+            #     if isinstance(mask, MaskArray):
+            #         # HACK: see previous hack
+            #         assert len(mask.shape) == 2
+            #         mask2 = MaskArray(mask.data[None])
+            #         rles = mask2.to_coco_rle(record["height"], record["width"])
+            #         annotations_dict["segmentation"].extend(rles)
+            #     elif isinstance(mask, Polygon):
+            #         annotations_dict["segmentation"].append(mask.points)
+            #     elif isinstance(mask, RLE):
+            #         coco_rle = {
+            #             "counts": mask.to_coco(),
+            #             "size": [record["height"], record["width"]],
+            #         }
+            #         annotations_dict["segmentation"].append(coco_rle)
+            #     elif isinstance(mask, MaskFile):
+            #         rles = mask.to_coco_rle(record["height"], record["width"])
+            #         annotations_dict["segmentation"].extend(rles)
+            #     elif isinstance(mask, EncodedRLEs):
+            #         annotations_dict["segmentation"].append(mask.erles)
+            #     else:
+            #         msg = f"Mask type {type(mask)} unsupported"
+            #         raise ValueError(msg)
 
     # TODO: is auto assigning a value for iscrowds dangerous (may hurt the metric value?)
     if "iscrowds" not in record:
@@ -125,12 +140,18 @@ def convert_record_to_coco_annotations(record):
     return annotations_dict
 
 
-def convert_preds_to_coco_style(preds):
-    return convert_records_to_coco_style(records=preds, images=True, categories=False)
+def convert_preds_to_coco_style(preds, show_pbar: bool = False):
+    return convert_records_to_coco_style(
+        records=preds, images=True, categories=False, show_pbar=show_pbar
+    )
 
 
 def convert_records_to_coco_style(
-    records, images: bool = True, annotations: bool = True, categories: bool = True
+    records,
+    images: bool = True,
+    annotations: bool = True,
+    categories: bool = True,
+    show_pbar: bool = True,
 ):
     """Converts records from library format to coco format.
     Inspired from: https://github.com/pytorch/vision/blob/master/references/detection/coco_utils.py#L146
@@ -138,7 +159,7 @@ def convert_records_to_coco_style(
     images_ = []
     annotations_dict = defaultdict(list)
 
-    for record in pbar(records):
+    for record in pbar(records, show=show_pbar):
         if images:
             image_ = convert_record_to_coco_image(record)
             images_.append(image_)
