@@ -44,7 +44,6 @@ def show_record(
     display_mask: bool = True,
     ax: plt.Axes = None,
     show: bool = False,
-    prepare_record: Optional[callable] = None,
 ) -> None:
     img = draw_record(
         record=record,
@@ -52,7 +51,6 @@ def show_record(
         display_label=display_label,
         display_bbox=display_bbox,
         display_mask=display_mask,
-        prepare_record=prepare_record,
     )
     show_img(img=img, ax=ax, show=show)
 
@@ -86,7 +84,6 @@ def show_records(
     display_label: bool = True,
     display_bbox: bool = True,
     display_mask: bool = True,
-    prepare_record: Optional[callable] = None,
     ncols: int = 1,
     figsize=None,
     show: bool = False,
@@ -99,7 +96,6 @@ def show_records(
             display_bbox=display_bbox,
             display_mask=display_mask,
             class_map=class_map,
-            prepare_record=prepare_record,
             show=False,
         )
         for record in records
@@ -135,7 +131,7 @@ def show_samples(
 
 
 def show_preds(
-    imgs: Sequence[np.ndarray],
+    samples: Union[Sequence[np.ndarray], Sequence[dict]],
     preds: Sequence[dict],
     class_map: Optional[ClassMap] = None,
     denormalize_fn: Optional[callable] = denormalize_imagenet,
@@ -146,24 +142,54 @@ def show_preds(
     figsize=None,
     show=False,
 ) -> None:
-    if not len(imgs) == len(preds):
+    if not len(samples) == len(preds):
         raise ValueError(
-            f"Number of imgs ({len(imgs)}) should be the same as "
+            f"Number of imgs ({len(samples)}) should be the same as "
             f"the number of preds ({len(preds)})"
         )
 
-    partials = [
-        partial(
-            show_pred,
-            img=img,
-            pred=pred,
-            class_map=class_map,
-            denormalize_fn=denormalize_fn,
-            display_label=display_label,
-            display_bbox=display_bbox,
-            display_mask=display_mask,
-            show=False,
-        )
-        for img, pred in zip(imgs, preds)
-    ]
-    plot_grid(partials, ncols=ncols, figsize=figsize, show=show)
+    if all(type(x) is dict for x in samples):
+        actuals = [
+            draw_sample(
+                sample=sample,
+                class_map=class_map,
+                display_label=display_label,
+                display_bbox=display_bbox,
+                display_mask=display_mask,
+                denormalize_fn=denormalize_fn,
+            )
+            for sample in samples
+        ]
+
+        imgs = [sample["img"] for sample in samples]
+        predictions = [
+            draw_pred(
+                img=img,
+                pred=pred,
+                class_map=class_map,
+                denormalize_fn=denormalize_fn,
+                display_label=display_label,
+                display_bbox=display_bbox,
+                display_mask=display_mask,
+            )
+            for img, pred in zip(imgs, preds)
+        ]
+
+        plot_grid_preds_actuals(actuals, predictions, figsize=figsize, show=show)
+
+    else:
+        partials = [
+            partial(
+                show_pred,
+                img=img,
+                pred=pred,
+                class_map=class_map,
+                denormalize_fn=denormalize_fn,
+                display_label=display_label,
+                display_bbox=display_bbox,
+                display_mask=display_mask,
+                show=False,
+            )
+            for img, pred in zip(samples, preds)
+        ]
+        plot_grid(partials, ncols=ncols, figsize=figsize, show=show)
